@@ -3,6 +3,4 @@
 
 from __future__ import absolute_import
 
-VERSION = '0.1.0'
-
-from .dotlink import Dotlink
+from .dotlink import Dotlink, VERSION
